face_mesh_stream_processor library

Classes

FaceDetectorStreamProcessor
Helper that turns a stream of camera frames into face detection results.
FaceMeshStreamProcessor
Helper that turns a stream of camera frames into MediaPipe results.

Functions

createFaceDetectorStreamProcessor(FaceDetectorProcessor processor) FaceDetectorStreamProcessor
Creates a detector stream processor for camera/image frames.
createFaceMeshStreamProcessor(FaceMeshProcessor processor) FaceMeshStreamProcessor
Creates a stream processor for camera/image frames.
faceMeshBoundingRect(FaceMeshResult result, {Size? targetSize, bool clampToBounds = true}) Rect
Returns the face bounding box in pixel coordinates.
faceMeshLandmarkOffset(FaceMeshResult result, FaceMeshLandmark landmark, {Size? targetSize, bool clampToBounds = true, int rotationDegrees = 0, bool mirrorHorizontal = false}) Offset
Converts a landmark to a pixel-space Offset.
faceMeshLandmarksOffsets(FaceMeshResult result, {Size? targetSize, bool clampToBounds = true, int rotationDegrees = 0, bool mirrorHorizontal = false}) List<Offset>
Converts all landmarks into pixel-space Offsets.

Typedefs

FaceDetectorRoiResolver<T> = NormalizedRect? Function(T frame)
Signature used to derive a detector ROI from an incoming frame.
FaceMeshBoxResolver<T> = FaceMeshBox? Function(T frame)
Signature used to derive a bounding box from an incoming frame.
FaceMeshRoiResolver<T> = NormalizedRect? Function(T frame)
Signature used to derive a normalized ROI from an incoming frame.