FaceDetectorStreamProcessor class
Helper that turns a stream of camera frames into face detection results.
Constructors
- FaceDetectorStreamProcessor(FaceDetectorProcessor _processor)
- Creates a processor bound to the given synchronous FaceDetectorProcessor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
Stream< FaceMeshImage> frames, {NormalizedRect? roi, FaceDetectorRoiResolver<FaceMeshImage> ? roiResolver, int rotationDegrees = 0, bool mirrorHorizontal = false, double? roiScaleX, double? roiScaleY, double? roiShiftX, double? roiShiftY}) → Stream<FaceDetectionResult> - Processes a stream of FaceMeshImage frames sequentially.
-
processNv21(
Stream< FaceMeshNv21Image> frames, {NormalizedRect? roi, FaceDetectorRoiResolver<FaceMeshNv21Image> ? roiResolver, int rotationDegrees = 0, bool mirrorHorizontal = false, double? roiScaleX, double? roiScaleY, double? roiShiftX, double? roiShiftY}) → Stream<FaceDetectionResult> - Processes NV21 camera frames coming from a stream.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited