FaceDetection class
Single face detection in normalized image coordinates.
Constructors
- FaceDetection({required double left, required double top, required double right, required double bottom, required double score, NormalizedRect? faceRect, NormalizedRect? expandedFaceRect})
-
Creates a normalized face detection box.
const
Properties
- bottom → double
-
Bottom edge in normalized coordinates.
final
- expandedFaceRect → NormalizedRect?
-
Expanded face ROI that matches MediaPipe's rect transformation step.
final
- faceRect → NormalizedRect?
-
Rotation-aware rect derived from the detection keypoints.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → double
-
Left edge in normalized coordinates.
final
- right → double
-
Right edge in normalized coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
Confidence score reported by the detector.
final
- top → double
-
Top edge in normalized coordinates.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBox(
{required int imageWidth, required int imageHeight}) → FaceMeshBox - Converts this normalized detection into a pixel-space FaceMeshBox.
-
toNormalizedRect(
{double scale = 1.0, bool makeSquare = false}) → NormalizedRect - Convenience normalized ROI for directly feeding Face Mesh.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited